# webman如何返回数据给浏览器
响应实际上是一个`support\Response`对象，为了方便创建这个对象，webman提供了一些助手函数。

## webman返回一个任意响应

**例子**
```php
<?php
namespace app\controller;

use support\Request;

class FooController
{
    public function hello(Request $request)
    {
        return response('hello webman');
    }
}
```

response函数实现如下：
```php
function response($body = '', $status = 200, $headers = array())
{
    return new Response($status, $headers, $body);
}
```

你也可以先创建一个空的`response`对象，然后在适当的位置利用`$response->cookie()` `$response->header()` `$response->withHeaders()` `$response->withBody()`设置返回内容。
```php
public function hello(Request $request)
{
    // 创建一个对象
    $response = response();
    
    // .... 业务逻辑省略
    
    // 设置cookie
    $response->cookie('foo', 'value');
    
    // .... 业务逻辑省略
    
    // 设置http头
    $response->header('Content-Type', 'application/json');
    $response->withHeaders([
                'X-Header-One' => 'Header Value 1',
                'X-Header-Tow' => 'Header Value 2',
            ]);

    // .... 业务逻辑省略

    // 设置要返回的数据
    $response->withBody('返回的数据');
    return $response;
}
```